pub enum MobileEnrollAction {
Start {
repo: String,
branch: String,
team_keys_path: String,
vault_path: Option<String>,
ttl_minutes: i64,
display_name: Option<String>,
json: bool,
qr: bool,
},
Accept {
start: PathBuf,
response: String,
team_keys: Option<PathBuf>,
identity: Option<PathBuf>,
json: bool,
},
}Variants
Start
Emit a public enrollment start envelope for mobile scanning.
Fields
Accept
Validate a mobile enrollment response, record its public recipient, and optionally rewrap the team vault.