ConfigAction

Enum ConfigAction 

pub enum ConfigAction {
    Show,
    SetBackupVault {
        target: String,
    },
    SetAutoQuickUnlock {
        mode: ToggleSetting,
    },
    SetQuickUnlockRetryCooldown {
        seconds: u64,
    },
    SetExecMode {
        mode: ExecModeSetting,
    },
    SetExecRedactOutput {
        mode: ToggleSetting,
    },
    SetExecCustomInherit {
        mode: ExecCustomInheritSetting,
    },
    SetExecCustomDenyDangerousEnv {
        mode: ToggleSetting,
    },
    AddExecExtraStrip {
        name: String,
    },
    RemoveExecExtraStrip {
        name: String,
    },
}
Global config.json settings (not tied to --profile).

Variants



Show

Show config file path, default profile, exec trust settings, and password-backup settings.



SetBackupVault

After each new password vault is created, copy its master password into this vault at profile-passwords/<new-profile> (recovery / main-vault bridging). Common values: main, default. Use off to disable.

Fields

target: String

Target vault profile (main, default) or off to clear.



SetAutoQuickUnlock

Persist whether normal vault opens should automatically try OS quick unlock.

Fields

mode: ToggleSetting

on to allow automatic keychain reads, off to require agent / env / typed password instead.



SetQuickUnlockRetryCooldown

Persist the retry cooldown, in seconds, after an automatic quick-unlock failure.

Fields

seconds: u64

Seconds to wait before the next automatic keychain attempt. Use 0 to disable the cooldown.



SetExecMode

Persist the default exec trust mode.

Fields

mode: ExecModeSetting

One of: standard, hardened, custom.



SetExecRedactOutput

Persist whether tsafe exec should redact child stdout/stderr by default.

Fields

mode: ToggleSetting

on to redact child output by default, off to leave it raw unless --redact-output is passed.



SetExecCustomInherit

Persist the inherit strategy used when exec mode is custom.

Fields

mode: ExecCustomInheritSetting

One of: full, minimal, clean.



SetExecCustomDenyDangerousEnv

Persist whether dangerous injected env names should abort exec when mode is custom.

Fields

mode: ToggleSetting

on to abort, off to warn only.



AddExecExtraStrip

Add a parent environment variable name to the extra strip list for tsafe exec.

Fields

name: String

Environment variable name, e.g. OPENAI_API_KEY.



RemoveExecExtraStrip

Remove a parent environment variable name from the extra strip list for tsafe exec.

Fields

name: String

Environment variable name, e.g. OPENAI_API_KEY.